@@ -27,11 +27,11 @@ api_format 'json';
 
 desc 'Actions on users',
 resource => user => sub {
-    params [
+    desc 'List users',
+    params => [
         optional => { name => 'start', type => Int, default => 0, desc => 'Pager (start)' },
         optional => { name => 'count', type => Int, default => 10, desc => 'Pager (count)' },
     ],
-    desc => 'List users',
     get => sub {
         my $params = shift;
 
@@ -55,12 +55,12 @@ resource => user => sub {
         { data => \@users }
     };
 
-    params [
+    desc 'Create new user',
+    params => [
         requires => { name => 'name', type => Str, desc => 'User name' },
         requires => { name => 'password', type => Str, desc => 'User password' },
         optional => { name => 'email', type => Str, default => undef, regex => qr/.+\@.+/, desc => 'User email' },
     ],
-    desc => 'Create new user',
     post => sub {
         my $params = shift;
 
@@ -70,7 +70,11 @@ resource => user => sub {
         { success => 1 }
     };
 
-    route_param { name => 'id', type => Int, desc => 'User ID' },
+    desc 'Actions on the user',
+    params => [
+        requires => { name => 'id', type => Int, desc => 'User ID' },
+    ],
+    route_param => 'id',
     sub {
         desc 'Show user',
         get => sub {
